@@ -25,9 +25,14 @@ def _get_jvm_platform_string() -> str:
         else:
             return "linux"
     elif platform.system() == "Darwin":
-        return "mac-os"
+        if platform.machine() == "arm64":
+            return "mac-os-arm64"
+        else:
+            return "mac-os"
     elif platform.system() == "OpenBSD":
-        return "openbsd"
+            return "openbsd-" + platform.machine()
+    else:
+        return "gamecore"
 
 
 def get_jvm_runtimes() -> List[str]:
